.. :changelog:


History
=======

0.9 (2015-05-11)
----------------

* Vastly improved documentation
* Bugfixes and changes based on early feedback
* New cmdtree module with two ingredients (for instantiating commands and for
  dispatching the invoked method)
* Simplified argparse ingredient (for just handling parser)
* Unit tests and doctests for some of the functionality

0.8 (2015-04-21)
----------------

* First release on PyPI.


2012-2015
---------

* Released on PyPI as a part of plainbox as ``plainbox.impl.clitools``,
  ``plainbox.impl.logging``, ``plainbox.i18n`` and
  ``plainbox.impl.secure.plugins``.
